You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/05 11:03:22 UTC

[21/32] incubator-ignite git commit: # Renaming

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsAdapter.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsAdapter.java
index afa7543..3eaa397 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsAdapter.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.streamer;
 
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsHolder.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsHolder.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsHolder.java
index cb76166..8a1c8bd 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsHolder.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageMetricsHolder.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.streamer;
 
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.*;
 import org.jdk8.backport.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageWrapper.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageWrapper.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageWrapper.java
index 4f55a78..d4b6486 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageWrapper.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerStageWrapper.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.streamer;
 
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsAdapter.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsAdapter.java
index b181fa7..6ba9800 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsAdapter.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.streamer;
 
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsHolder.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsHolder.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsHolder.java
index e7a1e02..599e57a 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsHolder.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/StreamerWindowMetricsHolder.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.streamer;
 
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 
 /**
  * Streamer window metrics holder.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerBroadcastTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerBroadcastTask.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerBroadcastTask.java
index d3df3fa..ccab0e6 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerBroadcastTask.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerBroadcastTask.java
@@ -14,9 +14,9 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.closure.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerQueryTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerQueryTask.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerQueryTask.java
index 8970e51..d10557b 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerQueryTask.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerQueryTask.java
@@ -14,9 +14,9 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.closure.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerReduceTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerReduceTask.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerReduceTask.java
index 48e55ce..0a236e5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerReduceTask.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/streamer/task/GridStreamerReduceTask.java
@@ -14,9 +14,9 @@ import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.closure.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/visor/node/VisorNodeDataCollectorJob.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/node/VisorNodeDataCollectorJob.java b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/node/VisorNodeDataCollectorJob.java
index 594d75e..b22eb37 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/node/VisorNodeDataCollectorJob.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/node/VisorNodeDataCollectorJob.java
@@ -3,6 +3,7 @@ package org.gridgain.grid.kernal.visor.node;
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.configuration.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.kernal.*;
@@ -12,7 +13,6 @@ import org.gridgain.grid.kernal.visor.cache.*;
 import org.gridgain.grid.kernal.visor.compute.*;
 import org.gridgain.grid.kernal.visor.ggfs.*;
 import org.gridgain.grid.kernal.visor.streamer.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.util.ipc.*;
 import org.gridgain.grid.util.typedef.internal.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerConfiguration.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerConfiguration.java b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerConfiguration.java
index 1d09d73..972a076 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerConfiguration.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerConfiguration.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.visor.streamer;
 
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerMetrics.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerConfiguration.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerConfiguration.java
deleted file mode 100644
index 9576a01..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerConfiguration.java
+++ /dev/null
@@ -1,267 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.gridgain.grid.util.typedef.internal.*;
-import org.gridgain.grid.util.tostring.*;
-import org.jetbrains.annotations.*;
-
-import java.util.*;
-import java.util.concurrent.*;
-
-/**
- * Streamer configuration.
- */
-public class StreamerConfiguration {
-    /** By default maximum number of concurrent sessions is unlimited. */
-    public static final int DFLT_MAX_CONCURRENT_SESSIONS = -1;
-
-    /** Default value for maximum failover attempts. */
-    public static final int DFLT_MAX_FAILOVER_ATTEMPTS = 3;
-
-    /** Name. */
-    private String name;
-
-    /** Window. */
-    private Collection<StreamerWindow> win;
-
-    /** Router. */
-    private StreamerEventRouter router;
-
-    /** Stages. */
-    @GridToStringInclude
-    private Collection<StreamerStage> stages;
-
-    /** At least once flag. */
-    private boolean atLeastOnce;
-
-    /** Maximum number of failover attempts. */
-    private int maxFailoverAttempts = DFLT_MAX_FAILOVER_ATTEMPTS;
-
-    /** Maximum number of concurrent sessions to be processed. */
-    private int maxConcurrentSessions = DFLT_MAX_CONCURRENT_SESSIONS;
-
-    /** Streamer executor service. */
-    private ExecutorService execSvc;
-
-    /** Executor service shutdown flag. */
-    private boolean execSvcShutdown;
-
-    /**
-     *
-     */
-    public StreamerConfiguration() {
-        // No-op.
-    }
-
-    /**
-     * @param c Configuration to copy.
-     */
-    public StreamerConfiguration(StreamerConfiguration c) {
-        atLeastOnce = c.isAtLeastOnce();
-        execSvc = c.getExecutorService();
-        execSvcShutdown = c.isExecutorServiceShutdown();
-        maxConcurrentSessions = c.getMaximumConcurrentSessions();
-        maxFailoverAttempts = c.getMaximumFailoverAttempts();
-        name = c.getName();
-        router = c.getRouter();
-        stages = c.getStages();
-        win = c.getWindows();
-    }
-
-    /**
-     * Gets streamer name. Must be unique within grid.
-     *
-     * @return Streamer name, if {@code null} then default streamer is returned.
-     */
-    @Nullable public String getName() {
-        return name;
-    }
-
-    /**
-     * Sets the name of the streamer.
-     *
-     * @param name Name.
-     */
-    public void setName(String name) {
-        this.name = name;
-    }
-
-    /**
-     * Gets streamer event router.
-     *
-     * @return Event router, if {@code null} then events will be executed locally.
-     */
-    @SuppressWarnings("unchecked")
-    @Nullable public StreamerEventRouter getRouter() {
-        return router;
-    }
-
-    /**
-     * Sets router for streamer.
-     *
-     * @param router Router.
-     */
-    public void setRouter(StreamerEventRouter router) {
-        this.router = router;
-    }
-
-    /**
-     * Gets collection of streamer event windows. At least one window should be configured. Each window
-     * must have unique name.
-     *
-     * @return Streamer windows.
-     */
-    public Collection<StreamerWindow> getWindows() {
-        return win;
-    }
-
-    /**
-     * Sets collection of streamer windows.
-     *
-     * @param win Window.
-     */
-    public void setWindows(Collection<StreamerWindow> win) {
-        this.win = win;
-    }
-
-    /**
-     * Gets collection of streamer stages. Streamer must have at least one stage to execute. Each stage
-     * must have unique name.
-     *
-     * @return Collection of streamer stages.
-     */
-    public Collection<StreamerStage> getStages() {
-        return stages;
-    }
-
-    /**
-     * Sets stages.
-     *
-     * @param stages Stages.
-     */
-    public void setStages(Collection<StreamerStage> stages) {
-        this.stages = stages;
-    }
-
-    /**
-     * Gets flag indicating whether streamer should track event execution sessions and failover event execution
-     * if any failure detected or any node on which execution happened has left the grid before successful response
-     * is received.
-     * <p>
-     * Setting this flag to {@code true} will guarantee that all pipeline stages will be executed at least once for
-     * each group of event submitted to streamer (or failure listener will be notified if failover cannot succeed).
-     * However, it does not guarantee that each stage will be executed at most once.
-     *
-     * @return {@code True} if event should be processed at least once,
-     *      or {@code false} if failures can be safely ignored.
-     */
-    public boolean isAtLeastOnce() {
-        return atLeastOnce;
-    }
-
-    /**
-     * @param atLeastOnce {@code True} to guarantee that event will be processed at least once.
-     */
-    public void setAtLeastOnce(boolean atLeastOnce) {
-        this.atLeastOnce = atLeastOnce;
-    }
-
-    /**
-     * Gets maximum number of failover attempts to try when pipeline execution has failed. This parameter
-     * is ignored if {@link #isAtLeastOnce()} is set to {@code false}.
-     * <p>
-     * If not set, default value is
-     *
-     * @return Maximum number of failover attempts to try.
-     */
-    public int getMaximumFailoverAttempts() {
-        return maxFailoverAttempts;
-    }
-
-    /**
-     * Sets maximum number of failover attempts.
-
-     * @param maxFailoverAttempts Maximum number of failover attempts.
-     * @see #getMaximumFailoverAttempts()
-     */
-    public void setMaximumFailoverAttempts(int maxFailoverAttempts) {
-        this.maxFailoverAttempts = maxFailoverAttempts;
-    }
-
-    /**
-     * Gets maximum number of concurrent events to be processed by streamer. This property is taken into
-     * account when {@link #isAtLeastOnce()} is set to {@code true}. If not positive, number of sessions
-     * will not be limited by any value.
-     *
-     * @return Maximum number of concurrent events to be processed. If number of concurrent events is greater
-     *      then this value, caller will be blocked until enough responses are received.
-     */
-    public int getMaximumConcurrentSessions() {
-        return maxConcurrentSessions;
-    }
-
-    /**
-     * Sets maximum number of concurrent sessions.
-     *
-     * @param maxConcurrentSessions Maximum number of concurrent sessions.
-     * @see #getMaximumConcurrentSessions()
-     */
-    public void setMaximumConcurrentSessions(int maxConcurrentSessions) {
-        this.maxConcurrentSessions = maxConcurrentSessions;
-    }
-
-    /**
-     * Gets streamer executor service. Defines a thread pool in which streamer stages will be executed.
-     * <p>
-     * If not specified, thread pool executor with max pool size equal to number of cores will be created.
-     *
-     * @return Streamer executor service.
-     */
-    public ExecutorService getExecutorService() {
-        return execSvc;
-    }
-
-    /**
-     * Sets streamer executor service.
-     *
-     * @param execSvc Executor service to use.
-     * @see #getExecutorService()
-     */
-    public void setExecutorService(ExecutorService execSvc) {
-        this.execSvc = execSvc;
-    }
-
-    /**
-     * Flag indicating whether streamer executor service should be shut down on GridGain stop. If this flag
-     * is {@code true}, executor service will be shut down regardless of whether executor was specified externally
-     * or it was created by GridGain.
-     *
-     * @return {@code True} if executor service should be shut down on GridGain stop.
-     */
-    public boolean isExecutorServiceShutdown() {
-        return execSvcShutdown;
-    }
-
-    /**
-     * Sets flag indicating whether executor service should be shut down on GridGain stop.
-     *
-     * @param execSvcShutdown {@code True} if executor service should be shut down on GridGain stop.
-     * @see #isExecutorServiceShutdown()
-     */
-    public void setExecutorServiceShutdown(boolean execSvcShutdown) {
-        this.execSvcShutdown = execSvcShutdown;
-    }
-
-    /** {@inheritDoc} */
-    @Override public String toString() {
-        return S.toString(StreamerConfiguration.class, this);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerContext.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerContext.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerContext.java
deleted file mode 100644
index d6f720c..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerContext.java
+++ /dev/null
@@ -1,134 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.apache.ignite.cluster.*;
-import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
-
-import java.util.*;
-import java.util.concurrent.*;
-
-/**
- * Streamer context. Provides access to streamer local store, configured windows and various methods
- * to run streamer queries.
- */
-public interface StreamerContext {
-    /**
-     * Gets instance of dynamic grid projection including all nodes on which this streamer is running.
-     *
-     * @return Projection with all nodes on which streamer is configured.
-     */
-    public ClusterGroup projection();
-
-    /**
-     * Gets streamer local space. Note that all updates to this space will be local.
-     *
-     * @return Streamer local space.
-     */
-    public <K, V> ConcurrentMap<K, V> localSpace();
-
-    /**
-     * Gets default event window, i.e. window that is on the first place in streamer configuration.
-     *
-     * @return Default window.
-     */
-    public <E> StreamerWindow<E> window();
-
-    /**
-     * Gets streamer event window by window name, if no window with such
-     * name was configured {@link IllegalArgumentException} will be thrown.
-     *
-     * @param winName Window name.
-     * @return Window instance.
-     */
-    public <E> StreamerWindow<E> window(String winName);
-
-    /**
-     * For context passed to {@link StreamerStage#run(StreamerContext, Collection)} this method will
-     * return next stage name in execution pipeline. For context obtained from streamer object, this method will
-     * return first stage name.
-     *
-     * @return Next stage name depending on invocation context.
-     */
-    public String nextStageName();
-
-    /**
-     * Queries all streamer nodes deployed within grid. Given closure will be executed on each node on which streamer
-     * is configured. Streamer context local for that node will be passed to closure during execution. All results
-     * returned by closure will be added to result collection.
-     *
-     * @param clo Function to be executed on individual nodes.
-     * @return Result received from all streamers.
-     * @throws GridException If query execution failed.
-     */
-    public <R> Collection<R> query(IgniteClosure<StreamerContext, R> clo) throws GridException;
-
-    /**
-     * Queries streamer nodes deployed within grid. Given closure will be executed on those of passed nodes
-     * on which streamer is configured. Streamer context local for that node will be passed to closure during
-     * execution. All results returned by closure will be added to result collection.
-     *
-     * @param clo Function to be executed on individual nodes.
-     * @param nodes Optional list of nodes to execute query on, if empty, then all nodes on
-     *      which this streamer is running will be queried.
-     * @return Result received from all streamers.
-     * @throws GridException If query execution failed.
-     */
-    public <R> Collection<R> query(IgniteClosure<StreamerContext, R> clo, Collection<ClusterNode> nodes)
-        throws GridException;
-
-    /**
-     * Queries all streamer nodes deployed within grid. Given closure will be executed on each streamer node
-     * in the grid. No result is collected.
-     *
-     * @param clo Function to be executed on individual nodes.
-     * @throws GridException If closure execution failed.
-     */
-    public void broadcast(IgniteInClosure<StreamerContext> clo) throws GridException;
-
-    /**
-     * Queries streamer nodes deployed within grid. Given closure will be executed on those of passed nodes on
-     * which streamer is configured. No result is collected.
-     *
-     * @param clo Function to be executed on individual nodes.
-     * @param nodes Optional list of nodes to execute query on, if empty, then all nodes on
-     *      which this streamer is running will be queried.
-     * @throws GridException If closure execution failed.
-     */
-    public void broadcast(IgniteInClosure<StreamerContext> clo, Collection<ClusterNode> nodes) throws GridException;
-
-    /**
-     * Queries all streamer nodes deployed within grid. Given closure will be executed on each streamer node in
-     * the grid. Streamer context local for that node will be passed to closure during execution. Results returned
-     * by closure will be passed to given reducer.
-     *
-     * @param clo Function to be executed on individual nodes.
-     * @param rdc Reducer to reduce results received from remote nodes.
-     * @return Reducer result.
-     * @throws GridException If query execution failed.
-     */
-    public <R1, R2> R2 reduce(IgniteClosure<StreamerContext, R1> clo, IgniteReducer<R1, R2> rdc) throws GridException;
-
-    /**
-     * Queries streamer nodes deployed within grid. Given closure will be executed on those of passed nodes on which
-     * streamer is configured. Streamer context local for that node will be passed to closure during execution.
-     * Results returned by closure will be passed to given reducer.
-     *
-     * @param clo Function to be executed on individual nodes.
-     * @param rdc Reducer to reduce results received from remote nodes.
-     * @param nodes Optional list of nodes to execute query on, if empty, then all nodes on
-     *      which this streamer is running will be queried.
-     * @return Reducer result.
-     * @throws GridException If query execution failed.
-     */
-    public <R1, R2> R2 reduce(IgniteClosure<StreamerContext, R1> clo, IgniteReducer<R1, R2> rdc,
-        Collection<ClusterNode> nodes) throws GridException;
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouter.java
deleted file mode 100644
index ba748f6..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouter.java
+++ /dev/null
@@ -1,47 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.apache.ignite.cluster.*;
-import org.jetbrains.annotations.*;
-
-import java.util.*;
-
-/**
- * Streamer event router. Pluggable component that determines event execution flow across the grid.
- * Each time a group of events is submitted to streamer or returned to streamer by a stage, event
- * router will be used to select execution node for next stage.
- */
-public interface StreamerEventRouter {
-    /**
-     * Selects a node for given event that should be processed by a stage with given name.
-     *
-     * @param ctx Streamer context.
-     * @param stageName Stage name.
-     * @param evt Event to route.
-     * @return Node to route to. If this method returns {@code null} then the whole pipeline execution
-     *      will be terminated. All running and ongoing stages for pipeline execution will be
-     *      cancelled.
-     */
-    @Nullable public <T> ClusterNode route(StreamerContext ctx, String stageName, T evt);
-
-    /**
-     * Selects a node for given events that should be processed by a stage with given name.
-     *
-     * @param ctx Streamer context.
-     * @param stageName Stage name to route events.
-     * @param evts Events.
-     * @return Events to node mapping. If this method returns {@code null} then the whole pipeline execution
-     *      will be terminated. All running and ongoing stages for pipeline execution will be
-     *      cancelled.
-     */
-    @Nullable public <T> Map<ClusterNode, Collection<T>> route(StreamerContext ctx, String stageName,
-        Collection<T> evts);
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouterAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouterAdapter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouterAdapter.java
deleted file mode 100644
index aee0eaa..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerEventRouterAdapter.java
+++ /dev/null
@@ -1,52 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.apache.ignite.cluster.*;
-import org.gridgain.grid.util.*;
-import org.gridgain.grid.util.typedef.*;
-
-import java.util.*;
-
-/**
- * Streamer adapter for event routers.
- */
-public abstract class StreamerEventRouterAdapter implements StreamerEventRouter {
-    /** {@inheritDoc} */
-    @Override public <T> Map<ClusterNode, Collection<T>> route(StreamerContext ctx, String stageName,
-        Collection<T> evts) {
-        if (evts.size() == 1) {
-            ClusterNode route = route(ctx, stageName, F.first(evts));
-
-            if (route == null)
-                return null;
-
-            return Collections.singletonMap(route, evts);
-        }
-
-        Map<ClusterNode, Collection<T>> map = new GridLeanMap<>();
-
-        for (T e : evts) {
-            ClusterNode n = route(ctx, stageName, e);
-
-            if (n == null)
-                return null;
-
-            Collection<T> mapped = map.get(n);
-
-            if (mapped == null)
-                map.put(n, mapped = new ArrayList<>());
-
-            mapped.add(e);
-        }
-
-        return map;
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerFailureListener.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerFailureListener.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerFailureListener.java
deleted file mode 100644
index da34702..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerFailureListener.java
+++ /dev/null
@@ -1,36 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import java.util.*;
-
-/**
- * Streamer failure listener. Asynchronous callback passed to user in case of any failure determined by streamer.
- *
- * @see org.apache.ignite.IgniteStreamer#addStreamerFailureListener(StreamerFailureListener)
- *
- */
-public interface StreamerFailureListener {
-    /**
-     * Callback invoked when unrecoverable failure is detected by streamer.
-     * <p>
-     * If {@link StreamerConfiguration#isAtLeastOnce()} is set to {@code false}, then this callback
-     * will be invoked on node on which failure occurred. If {@link StreamerConfiguration#isAtLeastOnce()}
-     * is set to {@code true}, then this callback will be invoked on node on which
-     * {@link org.apache.ignite.IgniteStreamer#addEvents(Collection)} or its variant was called. Callback will be called if maximum
-     * number of failover attempts exceeded or failover cannot be performed (for example, if router
-     * returned {@code null}).
-     *
-     * @param stageName Failed stage name.
-     * @param evts Failed set of events.
-     * @param err Error cause.
-     */
-    public void onFailure(String stageName, Collection<Object> evts, Throwable err);
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMBean.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMBean.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMBean.java
deleted file mode 100644
index 1e5cf5f..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMBean.java
+++ /dev/null
@@ -1,161 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.apache.ignite.mbean.*;
-import org.jetbrains.annotations.*;
-
-/**
- * Streamer MBean interface.
- */
-@IgniteMBeanDescription("MBean that provides access to streamer description and metrics.")
-public interface StreamerMBean {
-    /**
-     * Gets streamer name.
-     *
-     * @return Streamer name.
-     */
-    @IgniteMBeanDescription("Streamer name.")
-    @Nullable public String getName();
-
-    /**
-     * Gets {@code atLeastOnce} configuration flag.
-     *
-     * @return {@code True} if {@code atLeastOnce} is configured.
-     */
-    @IgniteMBeanDescription("True if atLeastOnce is configured.")
-    public boolean isAtLeastOnce();
-
-    /**
-     * Gets size of stage futures map. This map is maintained only when {@code atLeastOnce} configuration
-     * flag is set to true.
-     *
-     * @return Stage future map size.
-     */
-    @IgniteMBeanDescription("Stage future map size.")
-    public int getStageFutureMapSize();
-
-    /**
-     * Gets size of batch futures map.
-     *
-     * @return Batch future map size.
-     */
-    @IgniteMBeanDescription("Batch future map size.")
-    public int getBatchFutureMapSize();
-
-    /**
-     * Gets number of stages currently being executed in streamer pool.
-     *
-     * @return Number of stages. Cannot be more than pool thread count.
-     */
-    @IgniteMBeanDescription("Number of stages currently being executed in streamer pool.")
-    public int getStageActiveExecutionCount();
-
-    /**
-     * Gets number of event batches currently waiting to be executed.
-     *
-     * @return Number of event batches waiting to be processed.
-     */
-    @IgniteMBeanDescription("Number of event batches currently waiting to be executed.")
-    public int getStageWaitingExecutionCount();
-
-    /**
-     * Gets total number of stages executed since last reset.
-     *
-     * @return Total number of stages executed since last reset.
-     */
-    @IgniteMBeanDescription("Total number of stages executed since last reset.")
-    public long getStageTotalExecutionCount();
-
-    /**
-     * Gets pipeline maximum execution time, i.e. time between execution start and time when last stage in pipeline
-     * returned empty map. If pipeline execution was split to different nodes, metrics for each split will be
-     * recorded independently.
-     *
-     * @return Pipeline maximum execution time.
-     */
-    @IgniteMBeanDescription("Pipeline maximum execution time.")
-    public long getPipelineMaximumExecutionTime();
-
-    /**
-     * Gets pipeline minimum execution time, i.e. time between execution start and time when last stage in pipeline
-     * returned empty map. If pipeline execution was split to different nodes, metrics for each split will be
-     * recorded independently.
-     *
-     * @return Pipeline minimum execution time.
-     */
-    @IgniteMBeanDescription("Pipeline minimum execution time.")
-    public long getPipelineMinimumExecutionTime();
-
-    /**
-     * Gets pipeline average execution time, i.e. time between execution start and time when last stage in pipeline
-     * returned empty map. If pipeline execution was split, metrics for each split will be recorded independently.
-     *
-     * @return Pipeline average execution time.
-     */
-    @IgniteMBeanDescription("Pipeline average execution time.")
-    public long getPipelineAverageExecutionTime();
-
-    /**
-     * Gets maximum number of unique nodes participated in pipeline execution. If pipeline execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Maximum number of unique nodes in pipeline execution.
-     */
-    @IgniteMBeanDescription("Maximum number of unique nodes participated in pipeline execution.")
-    public int getPipelineMaximumExecutionNodes();
-
-    /**
-     * Gets minimum number of unique nodes participated in pipeline execution. If pipeline execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Minimum number of unique nodes in pipeline execution.
-     */
-    @IgniteMBeanDescription("Minimum number of unique nodes participated in pipeline execution.")
-    public int getPipelineMinimumExecutionNodes();
-
-    /**
-     * Gets average number of unique nodes participated in pipeline execution. If pipeline execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Average number of unique nodes in pipeline execution.
-     */
-    @IgniteMBeanDescription("Average number of unique nodes participated in pipeline execution.")
-    public int getPipelineAverageExecutionNodes();
-
-    /**
-     * Gets number of current active sessions. Since event execution sessions are tracked only when
-     * {@code atLeastOnce} configuration property is set to {@code true}, this metric will be collected
-     * only in this case. When {@code atLeastOnce} is set to {@code false}, this metric will always be zero.
-     *
-     * @return Number of current active sessions.
-     */
-    @IgniteMBeanDescription("Number of current active sessions.")
-    public int getCurrentActiveSessions();
-
-    /**
-     * Gets maximum number of active sessions since last reset. Since event execution sessions are tracked only when
-     * {@code atLeastOnce} configuration property is set to {@code true}, this metric will be collected
-     * only in this case. When {@code atLeastOnce} is set to {@code false}, this metric will always be zero.
-     *
-     * @return Maximum active sessions since last reset.
-     */
-    @IgniteMBeanDescription("Maximum number of active sessions since last reset.")
-    public int getMaximumActiveSessions();
-
-    /**
-     * Gets number of failures since last reset. If {@code atLeastOnce} flag is set to steamer configuration,
-     * then only root node failures will be counted. Otherwise each node will count failures independently.
-     *
-     * @return Failures count.
-     */
-    @IgniteMBeanDescription("Number of failures since last reset.")
-    public int getFailuresCount();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMetrics.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMetrics.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMetrics.java
deleted file mode 100644
index 4d47491..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerMetrics.java
+++ /dev/null
@@ -1,201 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import java.util.*;
-
-/**
- * Streamer metrics.
- */
-public interface StreamerMetrics {
-    /**
-     * Gets number of stages currently being executed in streamer pool.
-     *
-     * @return Number of stages. Cannot be more than pool thread count.
-     */
-    public int stageActiveExecutionCount();
-
-    /**
-     * Gets number of event batches currently waiting to be executed.
-     *
-     * @return Number of event batches waiting to be processed.
-     */
-    public int stageWaitingExecutionCount();
-
-    /**
-     * Gets total number of stages executed since last reset.
-     *
-     * @return Total number of stages executed since last reset.
-     */
-    public long stageTotalExecutionCount();
-
-    /**
-     * Gets pipeline maximum execution time, i.e. time between execution start and time when last stage in pipeline
-     * returned empty map. If pipeline execution was split to different nodes, metrics for each split will be
-     * recorded independently.
-     *
-     * @return Pipeline maximum execution time.
-     */
-    public long pipelineMaximumExecutionTime();
-
-    /**
-     * Gets pipeline minimum execution time, i.e. time between execution start and time when last stage in pipeline
-     * returned empty map. If pipeline execution was split to different nodes, metrics for each split will be
-     * recorded independently.
-     *
-     * @return Pipeline minimum execution time.
-     */
-    public long pipelineMinimumExecutionTime();
-
-    /**
-     * Gets pipeline average execution time, i.e. time between execution start and time when last stage in pipeline
-     * returned empty map. If pipeline execution was split, metrics for each split will be recorded independently.
-     *
-     * @return Pipeline average execution time.
-     */
-    public long pipelineAverageExecutionTime();
-
-    /**
-     * Gets maximum number of unique nodes participated in pipeline execution. If pipeline execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Maximum number of unique nodes in pipeline execution.
-     */
-    public int pipelineMaximumExecutionNodes();
-
-    /**
-     * Gets minimum number of unique nodes participated in pipeline execution. If pipeline execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Minimum number of unique nodes in pipeline execution.
-     */
-    public int pipelineMinimumExecutionNodes();
-
-    /**
-     * Gets average number of unique nodes participated in pipeline execution. If pipeline execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Average number of unique nodes in pipeline execution.
-     */
-    public int pipelineAverageExecutionNodes();
-
-    /**
-     * Gets query maximum execution time. If query execution was split to different nodes, metrics for each split
-     * will be recorded independently.
-     *
-     * @return Query maximum execution time.
-     */
-    public long queryMaximumExecutionTime();
-
-    /**
-     * Gets query minimum execution time. If query execution was split to different nodes, metrics for each split
-     * will be recorded independently.
-     *
-     * @return Query minimum execution time.
-     */
-    public long queryMinimumExecutionTime();
-
-    /**
-     * Gets query average execution time. If query execution was split to different nodes, metrics for each split
-     * will be recorded independently.
-     *
-     * @return Query average execution time.
-     */
-    public long queryAverageExecutionTime();
-
-    /**
-     * Gets maximum number of unique nodes participated in query execution. If query execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Maximum number of unique nodes in query execution.
-     */
-    public int queryMaximumExecutionNodes();
-
-    /**
-     * Gets minimum number of unique nodes participated in query execution. If query execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Minimum number of unique nodes in query execution.
-     */
-    public int queryMinimumExecutionNodes();
-
-    /**
-     * Gets average number of unique nodes participated in query execution. If query execution was split,
-     * metrics for each split will be recorded independently.
-     *
-     * @return Average number of unique nodes in query execution.
-     */
-    public int queryAverageExecutionNodes();
-
-    /**
-     * Gets number of current active sessions. Since event execution sessions are tracked only when
-     * {@code atLeastOnce} configuration property is set to {@code true}, this metric will be collected
-     * only in this case. When {@code atLeastOnce} is set to {@code false}, this metric will always be zero.
-     *
-     * @return Number of current active sessions.
-     */
-    public int currentActiveSessions();
-
-    /**
-     * Gets maximum number of active sessions since last reset. Since event execution sessions are tracked only when
-     * {@code atLeastOnce} configuration property is set to {@code true}, this metric will be collected
-     * only in this case. When {@code atLeastOnce} is set to {@code false}, this metric will always be zero.
-     *
-     * @return Maximum active sessions since last reset.
-     */
-    public int maximumActiveSessions();
-
-    /**
-     * Gets number of failures. If {@code atLeastOnce} flag is set to steamer configuration, then only root node
-     * failures will be counted. Otherwise each node will count failures independently.
-     *
-     * @return Failures count.
-     */
-    public int failuresCount();
-
-    /**
-     * Gets maximum number of threads in executor service.
-     *
-     * @return Maximum number of threads in executor service.
-     */
-    public int executorServiceCapacity();
-
-    /**
-     * Gets current stage metrics, if stage with given name is not configured
-     * then {@link IllegalArgumentException} will be thrown.
-     *
-     * @param stageName Stage name.
-     * @return Stage metrics.
-     */
-    public StreamerStageMetrics stageMetrics(String stageName);
-
-    /**
-     * Gets metrics for all stages. Stage metrics order is the same as stage order in configuration.
-     *
-     * @return Stage metrics collection.
-     */
-    public Collection<StreamerStageMetrics> stageMetrics();
-
-    /**
-     * Gets current window metrics, if window with given name is not configured
-     * then {@link IllegalArgumentException} will be thrown.
-     *
-     * @param winName Window name.
-     * @return Window metrics.
-     */
-    public StreamerWindowMetrics windowMetrics(String winName);
-
-    /**
-     * Gets metrics for all windows.
-     *
-     * @return Collection of window metrics.
-     */
-    public Collection<StreamerWindowMetrics> windowMetrics();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStage.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStage.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStage.java
deleted file mode 100644
index fc01059..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStage.java
+++ /dev/null
@@ -1,53 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.gridgain.grid.*;
-import org.jetbrains.annotations.*;
-
-import java.util.*;
-
-/**
- * Streamer stage is a component that determines event processing flow. User logic related to
- * any particular event processing is implemented by streamer stage. A stage takes events as
- * an input and returns groups of events mapped to different stages as an output. Events for
- * every returned stage will be passed to {@link StreamerEventRouter} which will determine
- * on which node the stage should be executed.
- * <p>
- * Generally, event stage execution graph if fully controlled by return values of
- * this method, while node execution graph is controlled by
- * {@link StreamerEventRouter#route(StreamerContext, String, Object)} method.
- */
-public interface StreamerStage<IN> {
-    /**
-     * Gets streamer stage name.
-     *
-     * @return Name of the stage.
-     */
-    public String name();
-
-    /**
-     * Stage execution routine. After the passed in events are processed, stage can emit
-     * another set of events to be processed. The returned events can be mapped to different
-     * stages. Events for every returned stage will be passed to {@link StreamerEventRouter}
-     * which will determine on which node the stage should be executed.
-     * <p>
-     * Generally, event stage execution graph if fully controlled by return values of
-     * this method, while node execution graph is controlled by
-     * {@link StreamerEventRouter#route(StreamerContext, String, Object)} method.
-     *
-     * @param ctx Streamer context.
-     * @param evts Input events.
-     * @return Map of stage name to collection of events.
-     * @throws GridException If failed.
-     */
-    @Nullable public Map<String, Collection<?>> run(StreamerContext ctx, Collection<IN> evts)
-        throws GridException;
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMBean.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMBean.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMBean.java
deleted file mode 100644
index e2be4c2..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMBean.java
+++ /dev/null
@@ -1,106 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.apache.ignite.mbean.*;
-
-/**
- * Streamer stage MBean.
- */
-@IgniteMBeanDescription("MBean that provides access to streamer stage description and metrics.")
-public interface StreamerStageMBean {
-    /**
-     * Gets stage name.
-     *
-     * @return Stage name.
-     */
-    @IgniteMBeanDescription("Stage name.")
-    public String getName();
-
-    /**
-     * Gets stage class name.
-     *
-     * @return Stage class name.
-     */
-    @IgniteMBeanDescription("Stage class name.")
-    public String getStageClassName();
-
-    /**
-     * Gets stage minimum execution time.
-     *
-     * @return Stage minimum execution time.
-     */
-    @IgniteMBeanDescription("Stage minimum execution time.")
-    public long getMinimumExecutionTime();
-
-    /**
-     * Gets stage maximum execution time.
-     *
-     * @return Stage maximum execution time.
-     */
-    @IgniteMBeanDescription("Stage maximum execution time.")
-    public long getMaximumExecutionTime();
-
-    /**
-     * Gets stage average execution time.
-     *
-     * @return Stage average execution time.
-     */
-    @IgniteMBeanDescription("Stage average execution time.")
-    public long getAverageExecutionTime();
-
-    /**
-     * Gets stage minimum waiting time.
-     *
-     * @return Stage minimum waiting time.
-     */
-    @IgniteMBeanDescription("Stage minimum waiting time.")
-    public long getMinimumWaitingTime();
-
-    /**
-     * Gets stage maximum waiting time.
-     *
-     * @return Stage maximum waiting time.
-     */
-    @IgniteMBeanDescription("Stage maximum waiting time.")
-    public long getMaximumWaitingTime();
-
-    /**
-     * Stage average waiting time.
-     *
-     * @return Stage average waiting time.
-     */
-    @IgniteMBeanDescription("Stage average waiting time.")
-    public long getAverageWaitingTime();
-
-    /**
-     * Gets total stage execution count since last reset.
-     *
-     * @return Number of times this stage was executed.
-     */
-    @IgniteMBeanDescription("Number of times this stage was executed.")
-    public long getTotalExecutionCount();
-
-    /**
-     * Gets stage failure count.
-     *
-     * @return Stage failure count.
-     */
-    @IgniteMBeanDescription("Stage failure count.")
-    public int getFailuresCount();
-
-    /**
-     * Gets flag indicating if stage is being currently executed by at least one thread on current node.
-     *
-     * @return {@code True} if stage is executing now.
-     */
-    @IgniteMBeanDescription("Whether stage is currently being executed.")
-    public boolean isExecuting();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMetrics.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMetrics.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMetrics.java
deleted file mode 100644
index 0cbc3c8..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerStageMetrics.java
+++ /dev/null
@@ -1,85 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-/**
- * Streamer stage metrics.
- */
-public interface StreamerStageMetrics {
-    /**
-     * Gets stage name.
-     *
-     * @return Stage name.
-     */
-    public String name();
-
-    /**
-     * Gets stage minimum execution time.
-     *
-     * @return Stage minimum execution time.
-     */
-    public long minimumExecutionTime();
-
-    /**
-     * Gets stage maximum execution time.
-     *
-     * @return Stage maximum execution time.
-     */
-    public long maximumExecutionTime();
-
-    /**
-     * Gets stage average execution time.
-     *
-     * @return Stage average execution time.
-     */
-    public long averageExecutionTime();
-
-    /**
-     * Gets stage minimum waiting time.
-     *
-     * @return Stage minimum waiting time.
-     */
-    public long minimumWaitingTime();
-
-    /**
-     * Gets stage maximum waiting time.
-     *
-     * @return Stage maximum waiting time.
-     */
-    public long maximumWaitingTime();
-
-    /**
-     * Stage average waiting time.
-     *
-     * @return Stage average waiting time.
-     */
-    public long averageWaitingTime();
-
-    /**
-     * Gets total stage execution count since last reset.
-     *
-     * @return Number of times this stage was executed.
-     */
-    public long totalExecutionCount();
-
-    /**
-     * Gets stage failure count.
-     *
-     * @return Stage failure count.
-     */
-    public int failuresCount();
-
-    /**
-     * Gets flag indicating if stage is being currently executed by at least one thread on current node.
-     *
-     * @return {@code True} if stage is executing now.
-     */
-    public boolean executing();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindow.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindow.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindow.java
deleted file mode 100644
index 6096ccc..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindow.java
+++ /dev/null
@@ -1,198 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.gridgain.grid.*;
-import org.gridgain.grid.streamer.index.*;
-import org.jetbrains.annotations.*;
-
-import java.util.*;
-
-/**
- * Streamer rolling window. Rolling windows allow new event to come in, as well as automatically
- * evicting obsolete events on the other side. Windows allow to query into specific time-frame
- * or specific sample size of the events. With windows, you can answer questions like "What
- * are my top 10 best selling products over last 24 hours?", or "Who are my top 10 users out of
- * last 1,000,000 users who logged in?"
- * <p>
- * GridGain comes with following rolling windows implementations out of the box:
- * <ul>
- * <li>{@link org.gridgain.grid.streamer.window.StreamerUnboundedWindow}</li>
- * <li>{@link org.gridgain.grid.streamer.window.StreamerBoundedSizeWindow}</li>
- * <li>{@link org.gridgain.grid.streamer.window.StreamerBoundedSizeBatchWindow}</li>
- * <li>{@link org.gridgain.grid.streamer.window.StreamerBoundedSizeSortedWindow}</li>
- * <li>{@link org.gridgain.grid.streamer.window.StreamerBoundedTimeWindow}</li>
- * <li>{@link org.gridgain.grid.streamer.window.StreamerBoundedTimeBatchWindow}</li>
- * </ul>
- * <p>
- * Streamer window is configured via {@link StreamerConfiguration#getWindows()} method.
- */
-public interface StreamerWindow<E> extends Iterable<E> {
-    /**
-     * Gets window name.
-     *
-     * @return Window name.
-     */
-    public String name();
-
-    /**
-     * Gets default index, if default index is not configured then
-     * {@link IllegalArgumentException} will be thrown.
-     *
-     * @param <K> Type of the index key.
-     * @param <V> Type of the index value.
-     * @return Index with default name.
-     */
-     public <K, V> StreamerIndex<E, K, V> index();
-
-    /**
-     * Gets index by name, if not index with such name was configured then
-     * {@link IllegalArgumentException} will be thrown.
-     *
-     * @param name Name of the index, if {@code null} then analogous to {@link #index()}.
-     * @param <K> Type of the index key.
-     * @param <V> Type of the index value.
-     * @return Index with a given name.
-     */
-    public <K, V> StreamerIndex<E, K, V> index(@Nullable String name);
-
-    /**
-     * Gets all indexes configured for this window.
-     *
-     * @return All indexes configured for this window or empty collection, if no
-     *         indexes were configured.
-     */
-    public Collection<StreamerIndex<E, ?, ?>> indexes();
-
-    /**
-     * Resets window. Usually will clear all events from window.
-     */
-    public void reset();
-
-    /**
-     * Gets number of events currently stored in window.
-     *
-     * @return Current size of the window.
-     */
-    public int size();
-
-    /**
-     * Gets number of entries available for eviction.
-     *
-     * @return Number of entries available for eviction.
-     */
-    public int evictionQueueSize();
-
-    /**
-     * Adds single event to window.
-     *
-     * @param evt Event to add.
-     * @return {@code True} if event was added.
-     * @throws GridException If index update failed.
-     */
-    public boolean enqueue(E evt) throws GridException;
-
-    /**
-     * Adds events to window.
-     *
-     * @param evts Events to add.
-     * @return {@code}
-     * @throws GridException If index update failed.
-     */
-    public boolean enqueue(E... evts) throws GridException;
-
-    /**
-     * Adds all events to window.
-     *
-     * @param evts Collection of events to add.
-     * @return {@code True} if all events were added, {@code false} if at
-     *      least 1 event was skipped.
-     * @throws GridException If index update failed.
-     */
-    public boolean enqueueAll(Collection<E> evts) throws GridException;
-
-    /**
-     * Dequeues last element from windows. Will return {@code null} if window is empty.
-     *
-     * @return Dequeued element.
-     * @throws GridException If index update failed.
-     */
-    @Nullable public E dequeue() throws GridException;
-
-    /**
-     * Dequeues up to {@code cnt} elements from window. If current window size is less than {@code cnt},
-     * will dequeue all elements from window.
-     *
-     * @param cnt Count to dequeue.
-     * @return Collection of dequeued elements.
-     * @throws GridException If index update failed.
-     */
-    public Collection<E> dequeue(int cnt) throws GridException;
-
-    /**
-     * Dequeues all elements from window.
-     *
-     * @return Collection of dequeued elements.
-     * @throws GridException If index update failed.
-     */
-    public Collection<E> dequeueAll() throws GridException;
-
-    /**
-     * If window supports eviction, this method will return next evicted element.
-     *
-     * @return Polls and returns next evicted event or {@code null} if eviction queue is empty or if
-     *      window does not support eviction.
-     * @throws GridException If index update failed.
-     */
-    @Nullable public E pollEvicted() throws GridException;
-
-    /**
-     * If window supports eviction, this method will return up to {@code cnt} evicted elements.
-     *
-     * @param cnt Number of elements to evict.
-     * @return Collection of evicted elements.
-     * @throws GridException If index update failed.
-     */
-    public Collection<E> pollEvicted(int cnt) throws GridException;
-
-    /**
-     * If window supports batch eviction, this method will poll next evicted batch from window.
-     * If windows does not support batch eviction but supports eviction, will return collection of single
-     * last evicted element.
-     * If window does not support eviction, will return empty collection.
-     *
-     * @return Next evicted batch.
-     * @throws GridException If index update failed.
-     */
-    public Collection<E> pollEvictedBatch() throws GridException;
-
-    /**
-     * If window supports eviction, this method will return all available evicted elements.
-     *
-     * @return Collection of evicted elements.
-     * @throws GridException If index update failed.
-     */
-    public Collection<E> pollEvictedAll() throws GridException;
-
-    /**
-     * Clears all evicted entries.
-     *
-     * @throws GridException If index update failed.
-     */
-    public void clearEvicted() throws GridException;
-
-    /**
-     * Create window snapshot. Evicted entries are not included.
-     *
-     * @param includeIvicted Whether to include evicted entries or not.
-     * @return Window snapshot.
-     */
-    public Collection<E> snapshot(boolean includeIvicted);
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMBean.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMBean.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMBean.java
deleted file mode 100644
index 16ff58e..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMBean.java
+++ /dev/null
@@ -1,50 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-import org.apache.ignite.mbean.*;
-
-/**
- * Streamer window MBean.
- */
-@IgniteMBeanDescription("MBean that provides access to streamer window description.")
-public interface StreamerWindowMBean {
-    /**
-     * Gets window name.
-     *
-     * @return Window name.
-     */
-    @IgniteMBeanDescription("Window name.")
-    public String getName();
-
-    /**
-     * Gets window class name.
-     *
-     * @return Window class name.
-     */
-    @IgniteMBeanDescription("Window class name.")
-    public String getClassName();
-
-    /**
-     * Gets current window size.
-     *
-     * @return Current window size.
-     */
-    @IgniteMBeanDescription("Window size.")
-    public int getSize();
-
-    /**
-     * Gets estimate for window eviction queue size.
-     *
-     * @return Eviction queue size estimate.
-     */
-    @IgniteMBeanDescription("Eviction queue size estimate.")
-    public int getEvictionQueueSize();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMetrics.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMetrics.java b/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMetrics.java
deleted file mode 100644
index e373866..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerWindowMetrics.java
+++ /dev/null
@@ -1,36 +0,0 @@
-/* @java.file.header */
-
-/*  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
- */
-
-package org.gridgain.grid.streamer;
-
-/**
- * Streamer window metrics.
- */
-public interface StreamerWindowMetrics {
-    /**
-     * Gets window name.
-     *
-     * @return Window name.
-     */
-    public String name();
-
-    /**
-     * Gets window size.
-     *
-     * @return Window size.
-     */
-    public int size();
-
-    /**
-     * Gets eviction queue size.
-     *
-     * @return Eviction queue size.
-     */
-    public int evictionQueueSize();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndex.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndex.java b/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndex.java
index 5f069cb..6a6da36 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndex.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndex.java
@@ -16,11 +16,11 @@ import java.util.*;
 /**
  * User view on streamer index. Streamer indexes are used for fast look ups into streamer windows.
  * <p>
- * Streamer index can be accessed from {@link org.gridgain.grid.streamer.StreamerWindow} via any of the following methods:
+ * Streamer index can be accessed from {@link org.apache.ignite.streamer.StreamerWindow} via any of the following methods:
  * <ul>
- * <li>{@link org.gridgain.grid.streamer.StreamerWindow#index()}</li>
- * <li>{@link org.gridgain.grid.streamer.StreamerWindow#index(String)}</li>
- * <li>{@link org.gridgain.grid.streamer.StreamerWindow#indexes()}</li>
+ * <li>{@link org.apache.ignite.streamer.StreamerWindow#index()}</li>
+ * <li>{@link org.apache.ignite.streamer.StreamerWindow#index(String)}</li>
+ * <li>{@link org.apache.ignite.streamer.StreamerWindow#indexes()}</li>
  * </ul>
  * <p>
  * Indexes are created and provided for streamer windows by {@link StreamerIndexProvider} which is

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndexProvider.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndexProvider.java b/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndexProvider.java
index 696f33f..124cc18 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndexProvider.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/index/StreamerIndexProvider.java
@@ -12,7 +12,7 @@ package org.gridgain.grid.streamer.index;
 import org.gridgain.grid.*;
 
 /**
- * Represents an actual instance of an index. Used by a {@link org.gridgain.grid.streamer.StreamerWindow}
+ * Represents an actual instance of an index. Used by a {@link org.apache.ignite.streamer.StreamerWindow}
  * to perform event indexing.
  * <p>
  * To configure index for a streamer window, use

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/package.html
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/package.html b/modules/core/src/main/java/org/gridgain/grid/streamer/package.html
deleted file mode 100644
index 055bbb9..0000000
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/package.html
+++ /dev/null
@@ -1,14 +0,0 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-<!--
-    @html.file.header
-    _________        _____ __________________        _____
-    __  ____/___________(_)______  /__  ____/______ ____(_)_______
-    _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
-    / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
-    \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
--->
-<html>
-<body>
-    Contains main <b>Streaming APIs.</b>
-</body>
-</html>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerAffinityEventRouter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerAffinityEventRouter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerAffinityEventRouter.java
index 1c7b783..35b7d08 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerAffinityEventRouter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerAffinityEventRouter.java
@@ -12,7 +12,7 @@ package org.gridgain.grid.streamer.router;
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerCacheAffinityEventRouter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerCacheAffinityEventRouter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerCacheAffinityEventRouter.java
index d5633e5..a674bae 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerCacheAffinityEventRouter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerCacheAffinityEventRouter.java
@@ -12,9 +12,9 @@ package org.gridgain.grid.streamer.router;
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.resources.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.kernal.*;
-import org.gridgain.grid.streamer.*;
 import org.jetbrains.annotations.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerLocalEventRouter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerLocalEventRouter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerLocalEventRouter.java
index 69054db..961a722 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerLocalEventRouter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerLocalEventRouter.java
@@ -12,7 +12,7 @@ package org.gridgain.grid.streamer.router;
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.typedef.*;
 
 import java.util.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRandomEventRouter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRandomEventRouter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRandomEventRouter.java
index f5bc4fb..ab8c082 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRandomEventRouter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRandomEventRouter.java
@@ -11,7 +11,7 @@ package org.gridgain.grid.streamer.router;
 
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.typedef.*;
 import org.jdk8.backport.*;
 import org.jetbrains.annotations.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRoundRobinEventRouter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRoundRobinEventRouter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRoundRobinEventRouter.java
index 27a2b3d..83351d0 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRoundRobinEventRouter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/router/StreamerRoundRobinEventRouter.java
@@ -10,7 +10,7 @@
 package org.gridgain.grid.streamer.router;
 
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 
 import java.util.*;
 import java.util.concurrent.atomic.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/window/StreamerWindowAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/streamer/window/StreamerWindowAdapter.java b/modules/core/src/main/java/org/gridgain/grid/streamer/window/StreamerWindowAdapter.java
index 83d9127..b8b8f26 100644
--- a/modules/core/src/main/java/org/gridgain/grid/streamer/window/StreamerWindowAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/streamer/window/StreamerWindowAdapter.java
@@ -11,9 +11,9 @@ package org.gridgain.grid.streamer.window;
 
 import org.apache.ignite.lang.*;
 import org.apache.ignite.lifecycle.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.streamer.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.streamer.index.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
----------------------------------------------------------------------
diff --git a/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml b/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
index b87dc2f..64363c5 100644
--- a/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
+++ b/modules/core/src/test/config/streamer/average/spring-streamer-average-base.xml
@@ -33,7 +33,7 @@
     <bean id="grid.cfg" class="org.apache.ignite.configuration.IgniteConfiguration" parent="base.grid.cfg">
         <property name="streamerConfiguration">
             <list>
-                <bean class="org.gridgain.grid.streamer.StreamerConfiguration">
+                <bean class="org.apache.ignite.streamer.StreamerConfiguration">
                     <property name="windows">
                         <bean class="org.gridgain.grid.streamer.window.StreamerBoundedSizeWindow">
                             <property name="maximumSize" value="500"/>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerEvictionSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerEvictionSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerEvictionSelfTest.java
index ba546df..37c6585 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerEvictionSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerEvictionSelfTest.java
@@ -11,11 +11,11 @@ package org.gridgain.grid.kernal.processors.streamer;
 
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.marshaller.optimized.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.spi.discovery.tcp.*;
 import org.gridgain.grid.spi.discovery.tcp.ipfinder.*;
 import org.gridgain.grid.spi.discovery.tcp.ipfinder.vm.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.streamer.window.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerFailoverSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerFailoverSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerFailoverSelfTest.java
index d386b95..a6f4891 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerFailoverSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerFailoverSelfTest.java
@@ -13,10 +13,10 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.spi.discovery.tcp.*;
 import org.gridgain.grid.spi.discovery.tcp.ipfinder.*;
 import org.gridgain.grid.spi.discovery.tcp.ipfinder.vm.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.streamer.window.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerLifecycleAwareSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerLifecycleAwareSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerLifecycleAwareSelfTest.java
index f8b7de3..e271eab 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerLifecycleAwareSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerLifecycleAwareSelfTest.java
@@ -11,7 +11,7 @@ package org.gridgain.grid.kernal.processors.streamer;
 
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.configuration.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.streamer.index.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
@@ -20,7 +20,7 @@ import org.jetbrains.annotations.*;
 import java.util.*;
 
 /**
- * Test for {@link org.apache.ignite.lifecycle.LifecycleAware} support in {@link org.gridgain.grid.streamer.StreamerConfiguration}.
+ * Test for {@link org.apache.ignite.lifecycle.LifecycleAware} support in {@link org.apache.ignite.streamer.StreamerConfiguration}.
  */
 public class GridStreamerLifecycleAwareSelfTest extends GridAbstractLifecycleAwareSelfTest {
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
index ce9cfc5..00faa98 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
@@ -15,11 +15,11 @@ import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.marshaller.optimized.*;
 import org.apache.ignite.resources.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.spi.discovery.tcp.*;
 import org.gridgain.grid.spi.discovery.tcp.ipfinder.*;
 import org.gridgain.grid.spi.discovery.tcp.ipfinder.vm.*;
-import org.gridgain.grid.streamer.*;
 import org.gridgain.grid.streamer.router.*;
 import org.gridgain.grid.streamer.window.*;
 import org.gridgain.grid.util.typedef.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStage.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStage.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStage.java
index 397160a..cb35b47 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStage.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStage.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.streamer;
 
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.*;
-import org.gridgain.grid.streamer.*;
 
 import java.util.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStreamerEventRouter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStreamerEventRouter.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStreamerEventRouter.java
index fd9b642..d8d0e25 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStreamerEventRouter.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridTestStreamerEventRouter.java
@@ -10,7 +10,7 @@
 package org.gridgain.grid.kernal.processors.streamer;
 
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 
 import java.util.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/SC.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/SC.java b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/SC.java
index ab33222..3c6f47e 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/SC.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/SC.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.streamer;
 
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.lang.*;
 
 import java.util.*;
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerMetrics.java b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerMetrics.java
index 1717333..703ba11 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerMetrics.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerMetrics.java
@@ -10,13 +10,13 @@
 package org.gridgain.grid.kernal.visor.streamer;
 
 import org.apache.ignite.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 import java.io.*;
 
 /**
  * Data transfer object for {@link org.gridgain.grid.streamer.StreamerMetrics}.
  */
 public class VisorStreamerMetrics implements Serializable {
     /** */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerStageMetrics.java
----------------------------------------------------------------------
@@ -10,13 +10,13 @@
 
 /**
- * Data transfer object for {@link org.gridgain.grid.streamer.StreamerMetrics}.
+ * Data transfer object for {@link org.apache.ignite.streamer.StreamerMetrics}.
  */
 public class VisorStreamerMetrics implements Serializable {
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerStageMetrics.java b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerStageMetrics.java
index ade0027..c607581 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerStageMetrics.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/visor/streamer/VisorStreamerStageMetrics.java
@@ -10,14 +10,14 @@
 package org.gridgain.grid.kernal.visor.streamer;
 
 import org.apache.ignite.*;
-import org.gridgain.grid.streamer.*;
+import org.apache.ignite.streamer.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 import java.io.*;
 import java.util.*;
 
 /**
  * Data transfer object for {@link org.gridgain.grid.streamer.StreamerStageMetrics}.
  */
 public class VisorStreamerStageMetrics implements Serializable {
     /** */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/42704cb9/modules/core/src/main/java/org/gridgain/grid/streamer/StreamerConfiguration.java
----------------------------------------------------------------------
@@ -10,14 +10,14 @@
 
 /**
- * Data transfer object for {@link org.gridgain.grid.streamer.StreamerStageMetrics}.
+ * Data transfer object for {@link org.apache.ignite.streamer.StreamerStageMetrics}.
  */
 public class VisorStreamerStageMetrics implements Serializable {